@@ -3,11 +3,13 @@ set -eox pipefail
 
 PREFIX=$(echo "${PREFIX}" | tr '\\' '/')
 
-if [[ "${target_platform}" == "win-64" ]]; then
+if [[ "${build_platform}" == "win-64" ]]; then
     DOTNET_ROOT="${PREFIX}/dotnet"
 else
     DOTNET_ROOT="${PREFIX}/lib/dotnet"
 fi
 
 mkdir -p "${DOTNET_ROOT}"
+cp -r ./dotnet/packs/ "${DOTNET_ROOT}/packs/"
 cp -r ./dotnet/sdk/ "${DOTNET_ROOT}/sdk/"
+cp -r ./dotnet/templates/ "${DOTNET_ROOT}/templates/"
